#
# spec file for package kubie
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global rustflags '-Clink-arg=-Wl,-z,relro,-z,now'

Name:           kubie
Version:        0.22.0
Release:        1.1
Summary:        A Kubernetes context switcher
License:        Zlib
URL:            https://github.com/sbstp/kubie
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
Source2:        cargo_config
Recommends:     fzf
BuildRequires:  cargo
BuildRequires:  rust >= 1.67.0

%description
kubie offers context switching, namespace switching and prompt modification in a
way that makes each shell independent from others. It also has support for
split configuration files, meaning it can load Kubernetes contexts from
multiple files. You can configure the paths where kubie will look for
contexts, see the settings section.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%prep
%autosetup -a1

mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
RUSTFLAGS=%{rustflags} cargo build --release --no-default-features

%install
RUSTFLAGS=%{rustflags} cargo install --root=%{buildroot}%{_prefix} --path .

# copy bash completion file
install -D -m 644 ./completion/kubie.bash %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# copy fish completion file
install -D -m 644 ./completion/kubie.fish %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# remove residue crate files
rm %{buildroot}%{_prefix}/.crates.toml
rm -f %{buildroot}%{_prefix}/.crates2.json

%files
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%changelog
* Wed Sep  6 2023 rombert@apache.org
- Update to version 0.22.0:
  * Version 0.22.0
  * Revert commit 4097062 (#161)
  * Bump rustls-webpki from 0.101.2 to 0.101.4 (#159)
  * Bump serde from 1.0.183 to 1.0.185 (#157)
  * Bump tempfile from 3.7.1 to 3.8.0 (#156)
  * Bump serde_json from 1.0.104 to 1.0.105 (#155)
  * Bump clap from 4.3.21 to 4.3.23 (#158)
  * Bump anyhow from 1.0.72 to 1.0.75 (#154)
  * Bump clap from 4.3.19 to 4.3.21 (#152)
  * Bump tempfile from 3.7.0 to 3.7.1 (#150)
  * Bump serde from 1.0.180 to 1.0.183 (#149)
* Sun Aug  6 2023 kastl@b1-systems.de
- Update to version 0.21.2:
  * Version 0.21.2
  * Fix nushell environment variable assignment (#148)
* Thu Aug  3 2023 kastl@b1-systems.de
- Update to version 0.21.1:
  * Version 0.21.1
  * export: prevent temporary file from being deleted on exit
  * Bump serde from 1.0.179 to 1.0.180 (#146)
  * Bump anyhow from 1.0.71 to 1.0.72 (#141)
  * Bump serde_json from 1.0.102 to 1.0.104 (#144)
  * Bump serde from 1.0.178 to 1.0.179 (#143)
  * Bump serde_yaml from 0.8.26 to 0.9.25 (#145)
  * Bump attohttpc from 0.24.1 to 0.26.0 (#142)
* Tue Aug  1 2023 kastl@b1-systems.de
- BuildRequire rust >= 1.67 to avoid failing builds
- Update to version 0.21.0:
  * Version 0.21.0
  * Bump dirs from 2.0.2 to 5.0.1 (#139)
  * Bump clap from 3.2.25 to 4.3.19 (#137)
  * Bump signal-hook from 0.3.15 to 0.3.17 (#138)
  * Bump serde from 1.0.171 to 1.0.178 (#136)
  * Bump tempfile from 3.6.0 to 3.7.0 (#135)
  * Create dependabot.yml
  * nits
  * fix build/clippy issues
  * feat: add export feature (#125)
  * Use ubuntu-latest instead of ubuntu-20.04
  * Update actions/checkout to v3
* Thu Jul 13 2023 kastl@b1-systems.de
- Update to version 0.20.1:
  * Version 0.20.1
  * Update runner images
* Wed Jul 12 2023 Johannes Kastl <kastl@b1-systems.de>
- modify _service file to always create the vendor.tar.xz file
* Wed Jul 12 2023 kastl@b1-systems.de
- Update to version 0.20.0:
  * Version 0.20.0
  * Run 'cargo update'
  * Run 'cargo clippy' and apply fixes
  * Run 'cargo fmt'
  * Update README.md
  * Add support for pre/post shell hooks to bash.
  * fix(nushell): Replace `remove_matches` by `replace`
  * feat(nushell): Add support for prompt in nushell
  * feat(nushell): Add support for nushell
* Fri Mar  3 2023 Johannes Kastl <kastl@b1-systems.de>
- bash-completion subpackage now Requires bash-completion
* Thu Feb  2 2023 kastl@b1-systems.de
- Update to version 0.19.3:
  * Version 0.19.3
  * Delete old release script
  * Github actions handle publish now
  * Apply clippy lints
  * Add job to publish to crates.io when tag is created
* Mon Jan 30 2023 kastl@b1-systems.de
- Update to version 0.19.2:
  * Version 0.19.2
  * Buffer KUBECONFIG serde_yaml writes in memory
  * Set 600 mode file permissions on temp KUBECONFIG
* Tue Nov 15 2022 kastl@b1-systems.de
- Update to version 0.19.1:
  * Version 0.19.1
  * Update dependencies
  * Update skim to 0.10.1, fix security alerts
  * Update attohttpc and use native certs with rustls
* Wed Sep  7 2022 kastl@b1-systems.de
- follow the build instructions from the README to exclude
  the self-update functionality:
  cargo build --release --no-default-feature
- Update to version 0.19.0:
  * Version 0.19.0
  * Clarify comments for distro maintainers
  * Run cargo update
  * Apply clippy lints
  * Make the download subcommand optional
  * Use native cargo strip feature instead of GNU strip
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.18.0:
  * Version 0.18.0
  * Restore --version flag, fixes #118
  * Set opt-level = "s" to reduce binary size
  * Update attohttpc
  * Update Cargo.lock
  * use skim to select context and namespace instead of fzf (#117)
* Thu Jul 28 2022 kastl@b1-systems.de
- Update to version 0.17.2:
  * Version 0.17.2
  * Restore serde lowercase enum variants #114
* Mon Jul 25 2022 kastl@b1-systems.de
- Update to version 0.17.1:
  * Version 0.17.1
  * Switch from structopt to clap
  * Update dependencies
  * fix bug where fish completion for contexts would not terminate
- remove zstd as BuildRequires, as cargo_vendor no longer spits out tar.zst files...
* Mon May 30 2022 kastl@b1-systems.de
- add zstd as BuildRequires, as cargo_vendor now spits out tar.zst files...
- Update to version 0.17.0:
  * Version 0.17.0
  * Cleanup dead code
  * fix: copy zsh_hisotry file
  * Add instructions for installing on Arch Linux
* Thu Feb 17 2022 Johannes Kastl <kastl@b1-systems.de>
- add subpackages for kubie bash-completion and fish-completion
* Sun Dec 12 2021 rombert@apache.org
- Update to version 0.16.0:
  * Version 0.16.0
  * replace troublesome indexing with pop function
  * fix subsequent prompt modifications
  * restrict KUBECONFIG value
  * preserve xonshrc configuration
  * add xonsh support
  * Version 0.15.3
  * Add proper support for overridden $ZDOTDIR (#92)
  * Version 0.15.2
  * Find ZSH dotfiles in $ZDOTDIR first, then $HOME
  * Add fish completions
  * README: add MacPorts install info (#86)
  * Update dependencies
  * Allow references to users and clusters outside the config file
  * Version 0.15.1
  * vuln: update dependencies to remove unsafe `generator` package (#80)
  * Version 0.15.0
  * Add linux arm static builds (#79)
  * Do not try to read directories as YAML when configs are loaded.
  * Fix autocomplete error (#75)
  * Version 0.14.1
  * Avoid using temporary file for state (#74)
  * Version 0.14.0
  * Convert to using --context-headers={Auto,Always,Never} flag style
  * Lowercase settings for behavior.print_context_in_exec
  * More idiomatic defaulting in settings
  * Better config for behavior.print_context_in_exec, more explicit CLI flags
  * Print context names when using kubie exec with wildcard
  * Version 0.13.4
  * Fix missing data dir bug + adjustements with paths (#70)
  * Version 0.13.3
  * Enhance state.json handling with parallel kubie processes (#67)
  * Version 0.13.2
  * Return error on no matching context
  * Update deps
* Wed Feb 17 2021 rombert@apache.org
- Update to version 0.13.1:
  * Version 0.13.1
  * Repair macos build (#61)
  * Version 0.13.0
  * Use fixed version of image in Github test actions
  * Add option to disable namespace validation (#60)
  * Build arm64 binary on macos-10.15
  * Run tests for pull requests
* Wed Feb  3 2021 Jan Engelhardt <jengelh@inai.de>
- Make summary usable.
* Wed Feb  3 2021 rombert@apache.org
- Update to version 0.12.1:
  * Version 0.12.1
  * Add Apple Sillicon build of kubie (#57)
  * Version 0.12.0
  * Update dependencies
  * Add test & release actions and make kubie fully static on Linux (#56)
  * Version 0.11.1
  * Update lock file
  * Version 0.11.0
  * Add support for unsetting namespace
  * Run fish as an interactive login shell
* Tue Feb  2 2021 Robert Munteanu <rombert@apache.org>
- Initial package
